@@ -1,7 +1,7 @@
 use super::super::utils::http_get;
 use super::utils::*;
 use crate::error::Result;
-use std::collections::HashMap;
+use std::collections::BTreeMap;
 
 const BASE_URL: &str = "https://dapi.binance.com";
 
